# toLisp

Convert structured YAML or JSON files into Lisp style S-expressions.

### Installation

```bash
pip install tolisp
```

### Usage

```bash
tolisp < yaml or json file input >
```

## Run Locally

Clone the repository:

```bash
git clone https://github.com/riAssinstAr/2Lisp
```

Build the package:

```bash
python setup.py sdist bdist_wheel
```

Install:

```bash
pip install .\dist\*.whl
```

NOTE: This project was a part of LFX mentorship task submission under RISC-V.
